@@ -13,12 +13,10 @@
 #' @return \code{x}: the coordinate of the stimulus along a segment
 #' @return \code{r.vec}: the r vector (saturation, distance from the center).
 #'
-#' @examples \dontrun{
+#' @examples
 #' data(flowers)
-#' vis.flowers <- vismodel(flowers, visual = 'canis')
-#' di.flowers <- colspace(vis.flowers, space = 'di')
-#' }
-#'
+#' vis.flowers <- vismodel(flowers, visual = "canis")
+#' di.flowers <- colspace(vis.flowers, space = "di")
 #' @author Thomas White \email{thomas.white026@@gmail.com}
 #'
 #' @export
@@ -33,7 +31,7 @@ dispace <- function(vismodeldata) {
   dat <- vismodeldata
 
   # if object is vismodel:
-  if ("vismodel" %in% attr(dat, "class")) {
+  if (is.vismodel(dat)) {
 
     # check if trichromat
     if (attr(dat, "conenumb") < 2) {
@@ -47,7 +45,7 @@ dispace <- function(vismodeldata) {
     # check if relative
     if (!attr(dat, "relative")) {
       dat <- dat[, 1:2]
-      dat <- dat / apply(dat, 1, sum)
+      dat <- dat / rowSums(dat)
       class(dat) <- class(vismodeldata)
       warning("Quantum catch are not relative, and have been transformed", call. = FALSE)
       attr(vismodeldata, "relative") <- TRUE
@@ -55,17 +53,24 @@ dispace <- function(vismodeldata) {
   }
 
   # if not, check if it has more (or less) than 2 columns
-
-  if (!("vismodel" %in% attr(dat, "class"))) {
+  else {
     if (ncol(dat) < 2) {
       stop("Input data is not a ", dQuote("vismodel"), " object and has fewer than two columns", call. = FALSE)
     }
     if (ncol(dat) == 2) {
-      warning("Input data is not a ", dQuote("vismodel"), " object; treating columns as standardized quantum catch for ", dQuote("s"), " and ", dQuote("l"), " receptors, respectively", call. = FALSE)
+      warning("Input data is not a ", dQuote("vismodel"),
+        " object; treating columns as standardized quantum catch for ",
+        dQuote("s"), " and ", dQuote("l"), " receptors, respectively",
+        call. = FALSE
+      )
     }
 
     if (ncol(dat) > 2) {
-      warning("Input data is not a ", dQuote("vismodel"), " object *and* has more than two columns; treating the first two columns as standardized quantum catch for ", dQuote("s"), ", and ", dQuote("l"), " receptors, respectively", call. = FALSE)
+      warning("Input data is not a ", dQuote("vismodel"),
+        " object *and* has more than two columns; treating the first two columns as standardized quantum catch for ",
+        dQuote("s"), ", and ", dQuote("l"), " receptors, respectively",
+        call. = FALSE
+      )
     }
 
     dat <- dat[, 1:2]
@@ -73,7 +78,7 @@ dispace <- function(vismodeldata) {
 
     # Check that all rows sum to 1 (taking into account R floating point issue)
     if (!isTRUE(all.equal(rowSums(dat), rep(1, nrow(dat)), check.attributes = FALSE))) {
-      dat <- dat / apply(dat, 1, sum)
+      dat <- dat / rowSums(dat)
       warning("Quantum catch are not relative, and have been transformed", call. = FALSE)
       attr(vismodeldata, "relative") <- TRUE
     }
@@ -83,7 +88,10 @@ dispace <- function(vismodeldata) {
     s <- dat[, "s"]
     l <- dat[, "l"]
   } else {
-    warning("Could not find columns named ", dQuote("s"), ", and ", dQuote("l"), ", using first two columns instead.", call. = FALSE)
+    warning("Could not find columns named ", dQuote("s"), ", and ",
+      dQuote("l"), ", using first two columns instead.",
+      call. = FALSE
+    )
     s <- dat[, 1]
     l <- dat[, 2]
   }
