@@ -20,16 +20,17 @@
 #'
 #' @export
 #'
-#' @examples \dontrun{
+#' @importFrom grDevices n2mfrow
+#'
+#' @examples
 #' data(sicalis)
 #' explorespec(sicalis, 3)
-#' explorespec(sicalis, 3, ylim = c(0, 100), legpos = c(500, 80))}
-#'
+#' explorespec(sicalis, 3, ylim = c(0, 100), legpos = c(500, 80))
 #' @author Pierre-Paul Bitton \email{bittonp@@uwindsor.ca}
 
-explorespec <- function(rspecdata, by = NULL, scale = c("equal", "free"), legpos = "topright", ...) {
-
-  # oPar <- par(no.readonly=TRUE)
+explorespec <- function(rspecdata, by = NULL,
+                        scale = c("equal", "free"),
+                        legpos = "topright", ...) {
   oPar <- par("mar", "oma", "ask", "mfrow")
   on.exit(par(oPar))
 
@@ -40,10 +41,6 @@ explorespec <- function(rspecdata, by = NULL, scale = c("equal", "free"), legpos
 
   scale <- match.arg(scale)
 
-  ## begin CE edit
-
-  by0 <- by
-
   # default by value
   if (is.null(by)) {
     by <- 1
@@ -54,54 +51,27 @@ explorespec <- function(rspecdata, by = NULL, scale = c("equal", "free"), legpos
   if (length(which(by == "wl")) != 0) {
     by <- by[-which(by == "wl")]
   }
-  # Handle when 'by' is a list of factors
-  # if (is.list(by)) {
-  #   wl_id <- sapply(1:length(by), function(x) which(by[[x]]=='wl'))  # extract wl columns
-  #   # remove 'wl' column from each vector in list
-  #   if (any(sapply(wl_id, length)!=0)) {
-  #     id <- which(sapply(wl_id, length)!=0)
-  #     by[id] <- lapply(by[id], "[", -unlist(wl_id)[id])
-  #   }
-  #   # check that wl column is the same for all vectors
-  #   if (length(unique(wl_id))==1) {
-  #     by <- do.call('paste', c(by, sep='.'))
-  #   } else {
-  #     stop("mismatch in column names of input vectors")
-  #   }
-  # }
   # Allow for means of every "by" data, if "by" is a single number
   # i.e. if by=3, average every 3 consecutive data of "data"
   if (length(by) == 1) {
-    nms <- names(rspecdata)[seq(1, length(names(rspecdata)), by = by)]
-    by <- rep(1:(length(rspecdata) / by), each = by)
+    by <- rep(seq_len(length(rspecdata) / by), each = by)
   }
   # check: does data have the same number of columns as the by vector?
   # TODO: this is actually alright if you are not plotting by a character vector
   # describing the species, type of patch, etc. (by=3 should work fine here, last
   # plot will only have fewer lines)
   if (dim(rspecdata)[2] != length(by) & !is.integer(by)) {
-    stop(paste(
-      "\n", dQuote(deparse(substitute(by))), "is not of same length as columns in",
+    stop(
+      dQuote(deparse(substitute(by))),
+      " is not of same length as columns in ",
       dQuote(deparse(substitute(data)))
-    ))
+    )
   }
 
   by <- factor(by)
 
-  # return(by)
-
   # number of 'by' groups
-  numby <- length(levels(by))
-
-  # by <- as.numeric(by)
-
-  if (numby <= 0) stop("Invalid by value") # is this needed anymore?
-
-  # nplots <- ceiling(dim(rspecdata)[2] / numby)
-
-  nplots <- numby
-
-  ##### end CE edit
+  numby <- nlevels(by)
 
   # setup multi-panel plot parameters
   if (numby <= 4) {
@@ -120,59 +90,37 @@ explorespec <- function(rspecdata, by = NULL, scale = c("equal", "free"), legpos
     yaxismult <- c(0.9, 1.8)
   }
 
-  if (nplots == 1) {
-    par(mfrow = c(1, 1))
+  if (numby <= 16) {
+    par(mfrow = n2mfrow(numby))
   }
-  if (nplots == 2) {
-    par(mfrow = c(1, 2), mar = c(5, 4, 4, 0.5) + 0.1)
-  }
-  if (nplots > 2 & nplots < 5) {
-    par(mfrow = c(2, 2), mar = c(5, 4, 0.5, 0.5) + 0.1)
-  }
-  if (nplots >= 5 & nplots < 7) {
-    par(mfrow = c(2, 3), mar = c(5, 4, 0.5, 0.5) + 0.1)
-  }
-  if (nplots >= 7 & nplots < 9) {
-    par(mfrow = c(2, 4), mar = c(5, 4, 0.5, 0.5) + 0.1)
-  }
-  if (nplots >= 9) {
-    par(mfrow = c(3, 4), mar = c(5, 4, 0.5, 0.5) + 0.1)
-  }
-  if (nplots > 12) {
+  else {
     par(ask = TRUE)
   }
 
+
   arg <- list(...)
 
   arg$x <- wl
 
   if (is.null(arg$col)) {
-    col_list <- c(
-      "#E41A1C", "#377EB8", "#4DAF4A", "#984EA3",
-      "#FF7F00", "#FFFF33", "#A65628", "#F781BF"
-    )
+    col_list <- viridisLite::viridis(max(table(by)))
   } else {
     col_list <- arg$col
   }
 
   par(mar = c(2, 2, 1, 1), oma = c(3, 3, 0, 0))
 
-  if (all(is.null(arg$ylim), scale == "equal")) {
+  if (is.null(arg$ylim) && scale == "equal") {
     arg$ylim <- c(min(rspecdata), max(rspecdata)) * yaxismult
   }
 
-
-
-
   # TODO: should be able to deal with this if there are NAs in the by vector
   if (anyNA(by)) {
     warning("NA values in by vector. please check.")
   }
 
-
-
   # Do the plotting
-  for (i in 1:nplots) {
+  for (i in seq_len(numby)) {
     if (numby == 1) {
       bloc <- data.frame(rspecdata[i])
     } else {
@@ -210,7 +158,7 @@ explorespec <- function(rspecdata, by = NULL, scale = c("equal", "free"), legpos
     leg <- names(bloc)
 
     if (!is.null(dim(bloc))) {
-      legcolor <- rep(col_list, length = dim(bloc)[2])
+      legcolor <- rep(col_list, length.out = dim(bloc)[2])
     } else {
       legcolor <- col_list
     }
