@@ -1,6 +1,9 @@
-#' Plot a tetrahedral color space
+#' Produces a 3D convex hull in tetrahedral colour space
 #'
-#' Produces a 3D convex hull in tetrahedral color space
+#' @param grid.alpha transparency of the volume polygon grid lines
+#' @param grid if \code{TRUE}, connects the polygon outlining the volume occupied by points (defaults to \code{TRUE})
+#' @param fill if \code{TRUE}, fills the volume occupied by points (WARNING: transparency
+#' is not saved properly if exported using \code{rgl.postscript})(defaults to \code{TRUE}).
 #'
 #' @return \code{tcsvol} creates a 3D convex hull within a \code{tcsplot} object.
 #'
@@ -25,11 +28,11 @@ tcsvol <- function(tcsdata, col = "black", alpha = 0.2,
 
   vol <- t(convhulln(tcsdata[, c("x", "y", "z")], options = "FA")$hull)
   coords <- tcsdata[, c("x", "y", "z")]
-  listvol <- split(vol, rep(1:ncol(vol), each = nrow(vol)))
+  listvol <- split(vol, rep(seq_len(ncol(vol)), each = nrow(vol)))
   ppairs <- do.call(rbind, lapply(listvol, function(x) t(combn(x, 2))))
 
   if (grid) {
-    for (i in 1:nrow(ppairs)) {
+    for (i in seq_len(nrow(ppairs))) {
       rgl::segments3d(coords[ppairs[i, ], "x"],
         coords[ppairs[i, ], "y"],
         coords[ppairs[i, ], "z"],
